Podiant Python client
=====================

![Build](https://git.steadman.io/podiant/python-client/badges/master/build.svg)
![Coverage](https://git.steadman.io/podiant/python-client/badges/master/coverage.svg)

A rudimentary Python client for the Podiant API.

## Quickstart

Install Podiant:

```sh
pip install podiant-client
```

## Running tests

Does the code actually work?

```
pytest podiant
```

## To do

- Support PUT, PATCH and DELETEs

## Credits

Tools used in rendering this package:

- [Cookiecutter](https://github.com/audreyr/cookiecutter)
- [`cookiecutter-djangopackage`](https://github.com/pydanny/cookiecutter-djangopackage)
